PyBaccarat: pybaccarat Namespace Reference

PyBaccarat visit the ministry of silly walks

Namespaces
pybaccarat Namespace Reference

This module is collection of classes used with playing the game Baccarat. More...

## Namespaces
| baccarat
| This module is collection of classes used with playing the game Baccarat.
| baccaratsystems
| This module is collection of classes used with systems for playing the game Baccarat.
| playingcards
| This module is collection of classes used with playing Cards.

## Detailed Description

This module is collection of classes used with playing the game Baccarat.

Classes:

- Hand
- Scoreboard
- Ties
- Game

Author
  fulkg.nosp@m.l@gm.nosp@m.ail.c.nosp@m.om

Version
  0.12